@@ -14,7 +14,7 @@ double hamming_dist(unsigned int *, int, unsigned int *, int);
 double lcs_dist(unsigned int *, int, unsigned int *, int, double *);
 double lv_dist(unsigned int *, int, unsigned int *, int, double *, double *);
 double osa_dist(unsigned int *, int, unsigned int *, int, double *, double *);
-double jaro_winkler_dist(unsigned int *, int, unsigned int *, int, double, double *, double *);
+double jaro_winkler_dist(unsigned int *, int, unsigned int *, int, double, double, double *, double *);
 qtree *new_qtree(int, int);
 void free_qtree();
 double qgram_dist(unsigned int *, int, unsigned int *t, int, unsigned int, qtree **, int);
